﻿using Microsoft.AspNetCore.Mvc;
using NPOI.SS.Formula.Functions;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using ZhonTai.Admin.Core.Consts;
using ZhonTai.Admin.Core.Dto;
using ZhonTai.Admin.Domain.Project;
using ZhonTai.Admin.Services.Project.Dto;
using ZhonTai.Common.Extensions;
using ZhonTai.DynamicApi;
using ZhonTai.DynamicApi.Attributes;

namespace ZhonTai.Admin.Services.Project
{
    /// <summary>
    /// 项目价格设置服务
    /// </summary>
    [Order(10)]
    [DynamicApi(Area = AdminConsts.AreaName)]
    public partial class ProjectPriceService : BaseService, IProjectService, IDynamicApi
    {
        private readonly IProjectRepository _projectRepository;
        private readonly IProjectPriceRepository _projectPriceRepository;

        public ProjectPriceService(IProjectRepository projectRepository, IProjectPriceRepository projectPriceRepository)
        {
            _projectRepository = projectRepository;
            _projectPriceRepository = projectPriceRepository;
        }

        /// <summary>
        /// 查询分页
        /// </summary>
        /// <param name="input"></param>
        /// <returns></returns>
        [HttpPost]
        public async Task<PageOutput<PriceGetPageOutput>> GetPageAsync(PageInput<PriceGetPageInput> input)
        {
            var list = await _projectRepository.Select
            .Count(out var total)
            .OrderByDescending(true, a => a.Id)
            .Page(input.CurrentPage, input.PageSize)
            .ToListAsync(a => new PriceGetPageOutput()
            {
                Id = a.Id,
                Name = a.Name,
                Logo = a.Logo,
                prices = _projectPriceRepository.Select.Where(m => m.ProjectId == a.Id).ToList<PriceGetPageOutput_Price>()
            });

            var data = new PageOutput<PriceGetPageOutput>()
            {
                List = Mapper.Map<List<PriceGetPageOutput>>(list),
                Total = total
            };

            return data;
        }
        /// <summary>
        /// 项目设置价格
        /// </summary>
        /// <param name="input"></param>
        /// <returns></returns>
        [HttpPost]
        public async Task<long> SetPriceAsync(PriceSetInput input)
        {
            //验证项目价格信息是否存在
            var price = await _projectPriceRepository.GetAsync(input.Id);
            if (!(price?.Id > 0))
            {
                throw ResultOutput.Exception("信息不存在,请刷新后重试！");
            }
            if (input.DrawPriceWay == 1)
            {
                //抽成比例
                if (input.DrawRatio < 0 || input.DrawRatio > 100)
                {
                    throw ResultOutput.Exception("抽成比例有效范围在0-100");
                }
                var amount = UtilConvertExtension.ToDecimalCutWithN(price.Price * input.DrawRatio * 0.01m, 0, 1);
                await _projectPriceRepository.UpdateDiy.SetSource(new ProjectPriceEntity()
                {
                    DrawPriceWay = input.DrawPriceWay,
                    DrawRatio = input.DrawRatio,
                    DrawPrice = amount,
                    Id = price.Id
                }).UpdateColumns(a => new { a.DrawPriceWay, a.DrawRatio, a.DrawPrice, a.ModifiedTime }).ExecuteAffrowsAsync();
            }
            else if (input.DrawPriceWay == 2)
            {
                //抽成金额
                if (input.DrawPrice > price.Price || input.DrawPrice < 0)
                {
                    throw ResultOutput.Exception("设置有效的抽成金额");
                }
                await _projectPriceRepository.UpdateDiy.SetSource(new ProjectPriceEntity()
                {
                    DrawPriceWay = input.DrawPriceWay,
                    DrawRatio = 0,
                    DrawPrice = input.DrawPrice,
                    Id = price.Id
                }).UpdateColumns(a => new { a.DrawPriceWay, a.DrawRatio, a.DrawPrice, a.ModifiedTime }).ExecuteAffrowsAsync(); ;
            }
            else
            {
                throw ResultOutput.Exception("无效的设价方式！");
            }
            return 1;
        }
    }
}